Returns TRUE if x inherits from class "hbb_fit", FALSE
otherwise. This is the recommended way to check whether an object
was produced by hbb().
See also
hbb() for fitting models.
Other fitting:
hbb(),
print.hbb_fit()
Returns TRUE if x inherits from class "hbb_fit", FALSE
otherwise. This is the recommended way to check whether an object
was produced by hbb().
hbb() for fitting models.
Other fitting:
hbb(),
print.hbb_fit()