Removes all cached compiled Stan executables and hash files from the persistent user-level cache directory. Also clears the in-memory session cache so that the next call to a fitting function will trigger fresh compilation.
Value
Invisibly returns TRUE if the disk cache existed and was
removed, FALSE if no cache was found.
See also
hbb_compile to compile Stan models.